@@ -1,6 +1,6 @@
 package Exporter::Declare;
 use strict;
-use warnings 'all';
+use warnings;
 
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
@@ -12,7 +12,7 @@ use aliased 'Exporter::Declare::Export::Generator';
 
 BEGIN { Meta->new(__PACKAGE__) }
 
-our $VERSION  = '0.111';
+our $VERSION  = '0.112';
 our @CARP_NOT = qw/
     Exporter::Declare
     Exporter::Declare::Specs
@@ -239,22 +239,7 @@ sub _find_export_class {
     my $args = shift;
 
     return shift(@$args)
-        if @$args && eval { $args->[0]->can('export_meta') };
-
-    # We cannot use $args->[0]->can('export_meta') here, even in eval. The
-    # issue is that in some conditions it will issue the warning 'can() called
-    # as function'.
-    # I cannot reproduce these conditions on my machine, but I do have a test
-    # machine that can reproduce them when Test::MockModule is loaded before
-    # loading an exporter.. This way of doing things fixes the issue on that
-    # machine.
-    if (@$args) {
-        my $arg = $args->[0];
-        no strict 'refs';
-        no warnings 'once';
-        return shift(@$args)
-            if defined *{"$arg\::export_meta"}{CODE};
-    }
+        if @$args && _is_exporter_class(@$args);
 
     return caller(1);
 }
